jactorch.parallel.user\_scattered
=================================

.. automodule:: jactorch.parallel.user_scattered

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      UserScatteredDataParallel
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      use_user_scattered
   
   

   
   
   








.. rubric:: Class UserScatteredDataParallel
.. autoclass:: UserScatteredDataParallel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: use_user_scattered


